==> drowl_paragraphs-8.x-2.8.tar.gz: drowl_paragraphs/modules/drowl_paragraphs_anchor_menu/js/drowl_paragraphs_anchor_menu.js <==
/**
 * @file
 * DROWL Paragraphs anchor menu JavaScript
 *
 */
(function ($, Drupal) {
  Drupal.behaviors.drowl_paragraphs_frontend = {
    attach: function (context, settings) {
      // Find paragraph onepage container sections and create an foundation magellan anchor menu out of them
      var $dynAnchorMenu = $('.top-bar-bottom-line .menu--anchor-menu:first', context);
      if ($dynAnchorMenu.length && $('[data-magellan-target]').length) {
        var $dynAnchorMenuDropdownPane = $dynAnchorMenu.parents('.dropdown-pane:first');
        var $dynAnchorMenuDropdownPaneToggleButton = $dynAnchorMenuDropdownPane.prev('.button--anchor-menu-dropdown-toggle');
        var becomeHorizontalMenuBreakpoint = $dynAnchorMenu.data('anchor-menu-horizontal-breakpoint');
        $('body:first').addClass('top-bar-has-bottom-line');
        $('[data-magellan-target]', context).each(function () {
          var $section = $(this);
          var sectionId = $section.attr('id');
          var sectionTitle = $section.data('magellan-title');
          $dynAnchorMenu.append('<li><a href="#' + sectionId + '">' + sectionTitle + '</a></li>');
        });
        // We have to initialize Magellan manually, otherwise the magellan navigation is not initialized correctly (using data-magellan doesn't work on dynamic menus).
        var zfMagellanDynAnchorMenu = new Foundation.Magellan($dynAnchorMenu, {
          offset: $('.top-bar-outer:first').outerHeight(),
          deeplinking: true
        });
        if (Foundation.MediaQuery.atLeast(becomeHorizontalMenuBreakpoint)) {
          $dynAnchorMenuDropdownPane.foundation('_destroy');
          if ($dynAnchorMenu.parent().is($dynAnchorMenuDropdownPane)) {
            // TODO: This needs a better solution - so we have an "undo". Maybe a clone of the magellan menu, one for mobile one for larger screens, so we can simply toggle the visibility.
            $dynAnchorMenu.unwrap();
            // also remove the toggle button
            $dynAnchorMenuDropdownPaneToggleButton.remove();
          }
        } else {
          // Small devices > set active section as dropdown toggle button text
          // Initally set first menu item as text
          var activeAnchorSectionName = $dynAnchorMenu.find('a:first').text();
          $dynAnchorMenuDropdownPaneToggleButton.text(activeAnchorSectionName);
          $dynAnchorMenu.on('update.zf.magellan', function () {
            var scopedAnchorSectionName = $dynAnchorMenu.find('a.is-active').text();
            if (scopedAnchorSectionName != activeAnchorSectionName && scopedAnchorSectionName != '') {
              $dynAnchorMenuDropdownPaneToggleButton.text(scopedAnchorSectionName);
            } else {
              $dynAnchorMenuDropdownPaneToggleButton.text(activeAnchorSectionName);
            }
          });
          // Close dropdown pane if an anchor link is clicked
          $dynAnchorMenu.find('a').on('click', function(){
            $dynAnchorMenuDropdownPane.foundation('close');
          });
        }
      }
    }
  }
})(jQuery, Drupal);

==> drowl_paragraphs-8.x-2.31.tar.gz: drowl_paragraphs/modules/drowl_paragraphs_anchor_menu/js/drowl_paragraphs_anchor_menu.js <==
/**
 * @file
 * DROWL Paragraphs anchor menu JavaScript
 *
 */
(function ($, Drupal) {
  Drupal.behaviors.drowl_paragraphs_frontend = {
    attach: function (context, settings) {
      // Find paragraph onepage container sections and create an foundation magellan anchor menu out of them
      var $dynAnchorMenu = $('.top-bar-bottom-line .menu--anchor-menu:first', context);
      if ($dynAnchorMenu.length && $('[data-magellan-target]').length) {
        var $dynAnchorMenuDropdownPane = $dynAnchorMenu.parents('.dropdown-pane:first');
        var $dynAnchorMenuDropdownPaneToggleButton = $dynAnchorMenuDropdownPane.prev('.button--anchor-menu-dropdown-toggle');
        var becomeHorizontalMenuBreakpoint = $dynAnchorMenu.data('anchor-menu-horizontal-breakpoint');
        $('body:first').addClass('top-bar-has-bottom-line');
        $('[data-magellan-target]', context).each(function () {
          var $section = $(this);
          var sectionId = $section.attr('id');
          var sectionTitle = $section.data('magellan-title');
          $dynAnchorMenu.append('<li><a href="#' + sectionId + '">' + sectionTitle + '</a></li>');
        });
        // We have to initialize Magellan manually, otherwise the magellan navigation is not initialized correctly (using data-magellan doesn't work on dynamic menus).
        var zfMagellanDynAnchorMenu = new Foundation.Magellan($dynAnchorMenu, {
          offset: $('.top-bar-outer:first').outerHeight(),
          deeplinking: true
        });
        if (Foundation.MediaQuery.atLeast(becomeHorizontalMenuBreakpoint)) {
          $dynAnchorMenuDropdownPane.foundation('_destroy');
          if ($dynAnchorMenu.parent().is($dynAnchorMenuDropdownPane)) {
            // TODO: This needs a better solution - so that we have an "undo". Maybe a clone of the magellan menu, one for mobile one for larger screens, so we can simply toggle the visibility.
            $dynAnchorMenu.unwrap();
            // also remove the toggle button
            $dynAnchorMenuDropdownPaneToggleButton.remove();
          }
        } else {
          // Small devices > set active section as dropdown toggle button text
          // Initally set first menu item as text
          var activeAnchorSectionName = $dynAnchorMenu.find('a:first').text();
          $dynAnchorMenuDropdownPaneToggleButton.text(activeAnchorSectionName);
          $dynAnchorMenu.on('update.zf.magellan', function () {
            var scopedAnchorSectionName = $dynAnchorMenu.find('a.is-active').text();
            if (scopedAnchorSectionName != activeAnchorSectionName && scopedAnchorSectionName != '') {
              $dynAnchorMenuDropdownPaneToggleButton.text(scopedAnchorSectionName);
            } else {
              $dynAnchorMenuDropdownPaneToggleButton.text(activeAnchorSectionName);
            }
          });
          // Close dropdown pane if an anchor link is clicked
          $dynAnchorMenu.find('a').on('click', function(){
            $dynAnchorMenuDropdownPane.foundation('close');
          });
        }
      }
    }
  }
})(jQuery, Drupal);
